Struct gitlab_client::common::KeysetPagination
source · pub struct KeysetPagination<TyOrderBy> {
pub per_page: Option<NonZeroU8>,
pub order_by: TyOrderBy,
pub sort: SortOrder,
}Expand description
Fields
per_page: Option<NonZeroU8>Number of items to list per page (default: 20, max: 100).
order_by: TyOrderBysort: SortOrderTrait Implementations
sourceimpl<TyOrderBy: Clone> Clone for KeysetPagination<TyOrderBy>
impl<TyOrderBy: Clone> Clone for KeysetPagination<TyOrderBy>
sourcefn clone(&self) -> KeysetPagination<TyOrderBy>
fn clone(&self) -> KeysetPagination<TyOrderBy>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<TyOrderBy: Debug> Debug for KeysetPagination<TyOrderBy>
impl<TyOrderBy: Debug> Debug for KeysetPagination<TyOrderBy>
sourceimpl<TyOrderBy: Hash> Hash for KeysetPagination<TyOrderBy>
impl<TyOrderBy: Hash> Hash for KeysetPagination<TyOrderBy>
sourceimpl<TyOrderBy: Ord> Ord for KeysetPagination<TyOrderBy>
impl<TyOrderBy: Ord> Ord for KeysetPagination<TyOrderBy>
sourcefn cmp(&self, other: &KeysetPagination<TyOrderBy>) -> Ordering
fn cmp(&self, other: &KeysetPagination<TyOrderBy>) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl<TyOrderBy: PartialEq> PartialEq for KeysetPagination<TyOrderBy>
impl<TyOrderBy: PartialEq> PartialEq for KeysetPagination<TyOrderBy>
sourcefn eq(&self, other: &KeysetPagination<TyOrderBy>) -> bool
fn eq(&self, other: &KeysetPagination<TyOrderBy>) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl<TyOrderBy: PartialOrd> PartialOrd for KeysetPagination<TyOrderBy>
impl<TyOrderBy: PartialOrd> PartialOrd for KeysetPagination<TyOrderBy>
sourcefn partial_cmp(&self, other: &KeysetPagination<TyOrderBy>) -> Option<Ordering>
fn partial_cmp(&self, other: &KeysetPagination<TyOrderBy>) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl<TyOrderBy: Copy> Copy for KeysetPagination<TyOrderBy>
impl<TyOrderBy: Eq> Eq for KeysetPagination<TyOrderBy>
impl<TyOrderBy> StructuralPartialEq for KeysetPagination<TyOrderBy>